@@ -13,36 +13,47 @@ async def bybit(**kwargs):
     await client.async_init()
     return client
 
+
 async def binance(**kwargs):
     """Create and initialize a Binance client instance."""
     client = BinanceClient(**kwargs)
     await client.async_init()
     return client
 
+
 async def okx(**kwargs):
     """Create and initialize an OKX client instance."""
     client = OKXClient(**kwargs)
     await client.async_init()
     return client
 
+
 async def bitmart(**kwargs):
     """Create and initialize a BitMart client instance."""
     client = BitmartClient(**kwargs)
     await client.async_init()
     return client
 
+
 async def gateio(**kwargs):
     """Create and initialize a Gate.io client instance."""
     client = GateioClient(**kwargs)
     await client.async_init()
     return client
 
+
 async def hyperliquid(**kwargs):
     """Create and initialize a Hyperliquid client instance."""
     client = HyperliquidClient(**kwargs)
     await client.async_init()
     return client
 
+
 __all__ = [
-    "bybit", "binance", "okx", "bitmart", "gateio", "hyperliquid",
+    "bybit",
+    "binance",
+    "okx",
+    "bitmart",
+    "gateio",
+    "hyperliquid",
 ]
