@@ -110,7 +110,9 @@ class TradeHTTP(HTTPManager):
 
         res = await self._request(
             method="POST",
-            path=SpotTrade.PLACE_CANCEL_QUERY_ORDER if self.ptm.get_exchange_type(Common.BINANCE, product_symbol=product_symbol) == BinanceExchangeType.SPOT else FuturesTrade.PLACE_CANCEL_QUERY_ORDER,
+            path=SpotTrade.PLACE_CANCEL_QUERY_ORDER
+            if self.ptm.get_exchange_type(Common.BINANCE, product_symbol=product_symbol) == BinanceExchangeType.SPOT
+            else FuturesTrade.PLACE_CANCEL_QUERY_ORDER,
             query=payload,
         )
         return res
@@ -297,7 +299,9 @@ class TradeHTTP(HTTPManager):
 
         res = await self._request(
             method="DELETE",
-            path=SpotTrade.PLACE_CANCEL_QUERY_ORDER if self.ptm.get_exchange_type(Common.BINANCE, product_symbol=product_symbol) == BinanceExchangeType.SPOT else FuturesTrade.PLACE_CANCEL_QUERY_ORDER,
+            path=SpotTrade.PLACE_CANCEL_QUERY_ORDER
+            if self.ptm.get_exchange_type(Common.BINANCE, product_symbol=product_symbol) == BinanceExchangeType.SPOT
+            else FuturesTrade.PLACE_CANCEL_QUERY_ORDER,
             query=payload,
         )
         return res
@@ -324,11 +328,13 @@ class TradeHTTP(HTTPManager):
 
         res = await self._request(
             method="GET",
-            path=SpotTrade.PLACE_CANCEL_QUERY_ORDER if self.ptm.get_exchange_type(Common.BINANCE, product_symbol=product_symbol) == BinanceExchangeType.SPOT else FuturesTrade.PLACE_CANCEL_QUERY_ORDER,
+            path=SpotTrade.PLACE_CANCEL_QUERY_ORDER
+            if self.ptm.get_exchange_type(Common.BINANCE, product_symbol=product_symbol) == BinanceExchangeType.SPOT
+            else FuturesTrade.PLACE_CANCEL_QUERY_ORDER,
             query=payload,
         )
         return res
-    
+
     async def get_open_orders(
         self,
         product_symbol: str,
@@ -336,14 +342,15 @@ class TradeHTTP(HTTPManager):
         payload = {}
         if product_symbol is not None:
             payload["symbol"] = self.ptm.get_exchange_symbol(Common.BINANCE, product_symbol)
-        
+
         res = await self._request(
             method="GET",
-            path=SpotTrade.QUERY_OPEN_ORDER if self.ptm.get_exchange_type(Common.BINANCE, product_symbol=product_symbol) == BinanceExchangeType.SPOT else FuturesTrade.QUERY_OPEN_ORDER,
+            path=SpotTrade.QUERY_OPEN_ORDER
+            if self.ptm.get_exchange_type(Common.BINANCE, product_symbol=product_symbol) == BinanceExchangeType.SPOT
+            else FuturesTrade.QUERY_OPEN_ORDER,
             query=payload,
         )
         return res
-        
 
     async def cancel_all_open_orders(
         self,
@@ -359,7 +366,9 @@ class TradeHTTP(HTTPManager):
 
         res = await self._request(
             method="DELETE",
-            path=SpotTrade.CANCEL_ALL_ORDERS if self.ptm.get_exchange_type(Common.BINANCE, product_symbol=product_symbol) == BinanceExchangeType.SPOT else FuturesTrade.CANCEL_ALL_OPEN_ORDERS,
+            path=SpotTrade.CANCEL_ALL_ORDERS
+            if self.ptm.get_exchange_type(Common.BINANCE, product_symbol=product_symbol) == BinanceExchangeType.SPOT
+            else FuturesTrade.CANCEL_ALL_OPEN_ORDERS,
             query=payload,
         )
         return res
